@@ -41,7 +41,6 @@
 #include "ui/itemview.h"
 #include "ui/liferea_shell.h"
 #include "ui/feed_list_view.h"
-#include "ui/liferea_htmlview.h"
 
 /* The 'item list' is a controller for 'item view' and database backend.
    It manages the currently displayed 'node', realizes filtering
@@ -176,15 +175,22 @@ itemlist_check_for_deferred_action (void)
 {
 	gulong	id = itemlist->priv->selectedId;
 	itemPtr	item;
+	gboolean  defer_remove;
 
 	if (id) {
 		itemlist_set_selected (NULL);
+                conf_get_bool_value (DEFER_DELETE_MODE, &defer_remove);
 
 		/* check for removals caused by itemlist filter rule */
 		if (itemlist->priv->deferredFilter) {
 			itemlist->priv->deferredFilter = FALSE;
 			item = item_load (id);
-			itemview_remove_item (item);
+                        item->isHidden = TRUE;
+                        if (defer_remove) {
+                                itemview_update_item (item);
+                        } else {
+                                itemview_remove_item (item);
+                        }
 			feed_list_view_update_node (item->nodeId);
 		}
 
@@ -233,6 +239,12 @@ itemlist_merge_item (itemPtr item)
 	itemview_add_item (item);
 }
 
+static void
+itemlist_merge_item_callback (itemPtr item, gpointer _unused)
+{
+	itemlist_merge_item (item);
+}
+
 /* Helper method checking if the passed item set is relevant
    for the currently item list content. */
 static gboolean
@@ -267,7 +279,7 @@ itemlist_merge_itemset (itemSetPtr itemSet)
 
 	if (itemlist_itemset_is_valid (itemSet)) {
 		debug_start_measurement (DEBUG_GUI);
-		itemset_foreach (itemSet, itemlist_merge_item);
+		itemset_foreach (itemSet, itemlist_merge_item_callback, NULL);
 		itemview_update ();
 		debug_end_measurement (DEBUG_GUI, "itemlist merge");
 	}
@@ -440,6 +452,7 @@ static void
 itemlist_unhide_item (itemPtr item)
 {
 	itemlist->priv->deferredFilter = FALSE;
+        item->isHidden = FALSE;
 }
 
 /* functions to remove items on remove requests */
@@ -536,11 +549,6 @@ itemlist_update_item (itemPtr item)
 		itemlist_unhide_item (item);
 	}
 
-	/* FIXME: this is tricky. It's possible that the item is
-	 * selected, but the itemview contains a webpage. In
-	 * that case, we don't want to reload the item.
-	 * So how to know whether the itemview contains the item?
-	 */
 	itemview_update_item (item);
 }
 
