@@ -40,7 +40,6 @@
 #include "itemset.h"
 #include "render.h"
 #include "xml.h"
-#include "ui/liferea_htmlview.h"
 
 /* Liferea provides special screens and the item and the feed displays
    using self-generated HTML. To separate code and layout and to easily
@@ -323,7 +322,7 @@ render_is_dark_theme (void)
 	return darkTheme;
 }
 
-const gchar *
+gchar *
 render_get_css (void)
 {
 	if (!css || styleUpdated) {
@@ -336,6 +335,9 @@ render_get_css (void)
 
 		styleUpdated = FALSE;
 
+		if (css)
+			g_string_free(css, FALSE);
+
 		css = g_string_new(NULL);
 
 		defaultStyleSheetFile = g_build_filename (PACKAGE_DATA_DIR, PACKAGE, "css", "liferea.css", NULL);
