@@ -1,7 +1,7 @@
 /*
  * @file item_list_view.c  presenting items in a GtkTreeView
  *
- * Copyright (C) 2004-2018 Lars Windolf <lars.windolf@gmx.de>
+ * Copyright (C) 2004-2022 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -70,8 +70,6 @@ enum is_columns {
 	IS_NR,			/*<< Item id, to lookup item ptr from parent feed */
 	IS_PARENT,		/*<< Parent node pointer */
 	IS_FAVICON,		/*<< Pixbuf reference to the item's feed's icon */
-	IS_ENCICON,		/*<< Pixbuf reference to the item's enclosure icon */
-	IS_ENCLOSURE,		/*<< Flag whether enclosure is attached or not */
 	IS_SOURCE,		/*<< Source node pointer */
 	IS_STATE,		/*<< Original item state (unread, flagged...) for sorting */
 	ITEMSTORE_WEIGHT,	/*<< Flag whether weight is to be bold and "unread" icon is to be shown */
@@ -295,8 +293,6 @@ item_list_view_create_tree_store (void)
 	                    G_TYPE_ULONG,	/* IS_NR */
 	                    G_TYPE_POINTER,	/* IS_PARENT */
 	                    G_TYPE_ICON,	/* IS_FAVICON */
-	                    G_TYPE_ICON,	/* IS_ENCICON */
-	                    G_TYPE_BOOLEAN,	/* IS_ENCLOSURE */
 	                    G_TYPE_POINTER,	/* IS_SOURCE */
 	                    G_TYPE_UINT,	/* IS_STATE */
 			    G_TYPE_INT,		/* ITEMSTORE_WEIGHT */
@@ -520,8 +516,6 @@ item_list_view_update_item_internal (ItemListView *ilv, itemPtr item, GtkTreeIte
                             IS_NR, item->id,
 			    IS_STATEICON, state_icon,
 			    ITEMSTORE_ALIGN, item_list_title_alignment (title),
-                            IS_ENCICON, item->hasEnclosure?icon_get (ICON_ENCLOSURE):NULL,
-                            IS_ENCLOSURE, item->hasEnclosure,
 		            IS_STATE, state,
 	                    ITEMSTORE_WEIGHT, fontWeight,
 			    -1);
@@ -534,8 +528,6 @@ item_list_view_update_item_internal (ItemListView *ilv, itemPtr item, GtkTreeIte
 			    IS_STATEICON, state_icon,
                             IS_PARENT, node,
                             IS_FAVICON, node_get_icon (node),
-                            IS_ENCICON, item->hasEnclosure?icon_get (ICON_ENCLOSURE):NULL,
-                            IS_ENCLOSURE, item->hasEnclosure,
                             IS_SOURCE, node,
                             IS_STATE, state,
 	                    ITEMSTORE_WEIGHT, fontWeight,
@@ -577,11 +569,8 @@ item_list_view_update_all_items (ItemListView *ilv)
 }
 
 void
-item_list_view_update (ItemListView *ilv, gboolean hasEnclosures)
+item_list_view_update (ItemListView *ilv)
 {
-	/* we depend on the fact that the third column is the enclosure icon column!!! */
-	gtk_tree_view_column_set_visible (g_hash_table_lookup(ilv->columns, "enclosure"), hasEnclosures);
-
 	if (ilv->batch_mode) {
                 gtk_widget_thaw_child_notify((GtkWidget *)ilv->treeview);
 		item_list_view_set_tree_store (ilv, ilv->batch_itemstore);
@@ -756,12 +745,12 @@ on_item_list_view_columns_changed (GtkTreeView *treeview, ItemListView *ilv)
 	GList *columns;
 	GHashTableIter iter;
 	gpointer colname, colptr;
-	gchar *strv[6];
+	gchar *strv[5];
 
 	/* This handler is only used for drag and drop reordering, so it
 	   should not be hooked up with less than the full number of columns
 	   eg: on item_list_view creation or teardown */
-	if (gtk_tree_view_get_n_columns(treeview) != 5)
+	if (gtk_tree_view_get_n_columns(treeview) != 4)
 		return;
 
 	columns = gtk_tree_view_get_columns (treeview);
@@ -824,6 +813,7 @@ item_list_view_create (gboolean wide)
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (ilv->ilscrolledwindow), GTK_SHADOW_IN);
 
 	ilv->treeview = GTK_TREE_VIEW (gtk_tree_view_new ());
+	gtk_tree_view_set_show_expanders (ilv->treeview, FALSE);
 	if (wide) {
 		gtk_tree_view_set_fixed_height_mode (ilv->treeview, FALSE);
 		gtk_tree_view_set_grid_lines (ilv->treeview, GTK_TREE_VIEW_GRID_LINES_HORIZONTAL);
@@ -845,7 +835,6 @@ item_list_view_create (gboolean wide)
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	column = gtk_tree_view_column_new_with_attributes ("", renderer, "gicon", IS_FAVICON, NULL);
 	g_object_set (renderer, "stock-size", wide?GTK_ICON_SIZE_DIALOG:GTK_ICON_SIZE_SMALL_TOOLBAR, NULL);
-
 	gtk_tree_view_column_set_sort_column_id (column, IS_SOURCE);
 	g_hash_table_insert (ilv->columns, "favicon", column);
 
@@ -867,16 +856,12 @@ item_list_view_create (gboolean wide)
 		gtk_tree_view_column_add_attribute (headline_column, renderer, "weight", ITEMSTORE_WEIGHT);
 	}
 
-	renderer = gtk_cell_renderer_pixbuf_new ();
-	column = gtk_tree_view_column_new_with_attributes ("", renderer, "gicon", IS_ENCICON, NULL);
-	g_hash_table_insert (ilv->columns, "enclosure", column);
-
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Date"), renderer,
 		                                           "text", IS_TIME_STR,
 	                                                   "weight", ITEMSTORE_WEIGHT,
 							   NULL);
-	gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_GROW_ONLY);
+	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_GROW_ONLY);
 	g_hash_table_insert (ilv->columns, "date", column);
 	gtk_tree_view_column_set_sort_column_id(column, IS_TIME);
 	if (wide)
@@ -885,8 +870,10 @@ item_list_view_create (gboolean wide)
 	conf_get_strv_value (LIST_VIEW_COLUMN_ORDER, &conf_column_order);
 	for (gchar **li = conf_column_order; *li; li++) {
 		column = g_hash_table_lookup (ilv->columns, *li);
-		g_object_set (column, "reorderable", TRUE, NULL);
-		gtk_tree_view_append_column (ilv->treeview, column);
+		if (GTK_IS_TREE_VIEW_COLUMN (column)) {
+			g_object_set (column, "reorderable", TRUE, NULL);
+			gtk_tree_view_append_column (ilv->treeview, column);
+		}
 	}
 	g_strfreev (conf_column_order);
 
