@@ -1153,6 +1153,7 @@ static const gchar * liferea_accels_zoom_reset[] = {"<Control>0", NULL};
 static const gchar * liferea_accels_search_feeds[] = {"<Control>f", NULL};
 static const gchar * liferea_accels_show_help_contents[] = {"F1", NULL};
 static const gchar * liferea_accels_open_selected_item_enclosure[] = {"<Control>o", NULL};
+static const gchar * liferea_accels_launch_item_in_external_browser[] = {"<Control>d", NULL};
 
 void
 liferea_shell_create (GtkApplication *app, const gchar *overrideWindowState, gint pluginsDisabled)
@@ -1223,6 +1224,7 @@ liferea_shell_create (GtkApplication *app, const gchar *overrideWindowState, gin
 	gtk_application_set_accels_for_action (app, "app.search-feeds", liferea_accels_search_feeds);
 	gtk_application_set_accels_for_action (app, "app.show-help-contents", liferea_accels_show_help_contents);
 	gtk_application_set_accels_for_action (app, "app.open-selected-item-enclosure", liferea_accels_open_selected_item_enclosure);
+	gtk_application_set_accels_for_action (app, "app.launch-item-in-external-browser", liferea_accels_launch_item_in_external_browser);
 
 	/* Toolbar */
 	gtk_builder_add_from_file (shell->xml, PACKAGE_DATA_DIR G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "liferea_toolbar.ui", NULL);
@@ -1356,17 +1358,6 @@ liferea_shell_destroy (void)
 	g_object_unref (shell);
 }
 
-void
-liferea_shell_present (void)
-{
-	GtkWidget *mainwindow = GTK_WIDGET (shell->window);
-
-	if ((gdk_window_get_state (gtk_widget_get_window (mainwindow)) & GDK_WINDOW_STATE_ICONIFIED) || !gtk_widget_get_visible (mainwindow))
-		liferea_shell_restore_position ();
-
-	gtk_window_present (shell->window);
-}
-
 static gboolean
 liferea_shell_window_is_on_other_desktop(GdkWindow *gdkwindow)
 {
