@@ -363,6 +363,15 @@ on_default_view_mode_changed (gpointer user_data)
 	conf_set_int_value (DEFAULT_VIEW_MODE, gtk_combo_box_get_active (GTK_COMBO_BOX (user_data)));
 }
 
+void
+on_deferdeletemode_toggled (GtkToggleButton *togglebutton, gpointer user_data)
+{
+	gboolean	enabled;
+
+	enabled = gtk_toggle_button_get_active (togglebutton);
+	conf_set_bool_value (DEFER_DELETE_MODE, enabled);
+}
+
 void
 on_enclosure_download_predefined_toggled (GtkToggleButton *button, gpointer user_data)
 {
@@ -541,6 +550,9 @@ preferences_dialog_init (PreferencesDialog *pd)
 	                            G_CALLBACK (on_default_view_mode_changed),
 	                            iSetting);
 
+	conf_get_bool_value (DEFER_DELETE_MODE, &bSetting);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->dialog, "deferdeletebtn")), bSetting?TRUE:FALSE);
+
 	/* Setup social bookmarking list */
 	i = 0;
 	conf_get_str_value (SOCIAL_BM_SITE, &name);
